#  tests for ephem-4.1.3-py39hb82d6ee_1 (this is a generated file);
print('===== testing package: ephem-4.1.3-py39hb82d6ee_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import ephem

mars = ephem.Mars()
mars.compute('2008/1/1')
assert str(mars.ra) == '5:59:27.35'
assert str(mars.dec) == '26:56:27.4'
#  --- run_test.py (end) ---

print('===== ephem-4.1.3-py39hb82d6ee_1 OK =====');
print("import: 'ephem'")
import ephem

print("import: 'ephem._libastro'")
import ephem._libastro

